@@ -19,27 +19,33 @@
 #ifndef DIALOG_OFFERSAVE_H
 #define DIALOG_OFFERSAVE_H
 
-#include <gnome--.h>
-#include "gnome--/messagebox.h"
-#include "gtk--/label.h"
-#include "gtk--/box.h"
-#include <libgnome/gnome-i18n.h>
+#include <bakeryconfig.h>
+
+#ifdef BAKERY_MAEMO_ENABLED
+#include <hildonmm/note.h>
+#else
+#include <gtkmm/messagedialog.h>
+#endif
 
 namespace Bakery
 {
 
-class Dialog_OfferSave : public Gnome::MessageBox
+#ifdef BAKERY_MAEMO_ENABLED
+class Dialog_OfferSave : public Hildon::Note
+#else
+class Dialog_OfferSave : public Gtk::MessageDialog
+#endif
 {
 public:
-  Dialog_OfferSave(const std::string& filepath);
+  Dialog_OfferSave(const Glib::ustring& file_uri);
   virtual ~Dialog_OfferSave();
 
-  //Return values:
+  ///Return values:
   enum enumButtons
   {
-    BUTTON_Save = 0,
-    BUTTON_Discard = 1,
-    BUTTON_Cancel = 2
+    BUTTON_Save,
+    BUTTON_Discard,
+    BUTTON_Cancel
   };
 
 };
